@@ -1,4 +1,4 @@
-from .validations import BadiValidators
+from src.badi_utils.validations import BadiValidators
 
 
 def test_validate_username(value):
